// use LGT8F328P-LQFP32 MiniEVB

#include <Adafruit_NeoPixel.h>
#ifdef __AVR__
 #include <avr/power.h> // Required for 16 MHz Adafruit Trinket
#endif


#define min_brightness -100
#define max_brightness 100

// Which pin on the Arduino is connected to the NeoPixels?
#define PIN        8 // On Trinket or Gemma, suggest changing this to 1

// How many NeoPixels are attached to the Arduino?
#define NUMPIXELS  2 // Popular NeoPixel ring size

// When setting up the NeoPixel library, we tell it how many pixels,
// and which pin to use to send signals. Note that for older NeoPixel
// strips you might need to change the third parameter -- see the
// strandtest example for more information on possible values.
Adafruit_NeoPixel pixels(NUMPIXELS, PIN, NEO_GRB + NEO_KHZ800);

#define DELAYVAL 500 // Time (in milliseconds) to pause between pixels

bool r=false,g=true,b=false;
int colorstyle = 0;


void setup() {
  // These lines are specifically to support the Adafruit Trinket 5V 16 MHz.
  // Any other board, you can remove this part (but no harm leaving it):
#if defined(__AVR_ATtiny85__) && (F_CPU == 16000000)
  clock_prescale_set(clock_div_1);
#endif
  // END of Trinket-specific code.

  pixels.begin(); // INITIALIZE NeoPixel strip object (REQUIRED)
}

void loop() {
//  pixels.clear(); // Set all pixel colors to 'off'

  // The first NeoPixel in a strand is #0, second is 1, all the way up
  // to the count of pixels minus one.
  int brightness = 0;

  int delaytime = 30;
  int calstep = 1;
  int cal = calstep;
    
  while ( 1 )
  {
      brightness = brightness + cal;
      
      for(int i=0; i<NUMPIXELS; i++) { // For each pixel...
        pixels.setPixelColor(i, GetColor(brightness));
      }
      
      pixels.show();   // Send the updated pixel colors to the hardware.
      delay(delaytime);

      if ( brightness > max_brightness ) cal = calstep * -1;
      if ( brightness < min_brightness ) {
        cal = calstep;
        // Switch color
        SwitchColor();
      }
  }
}

void SwitchColor() {
  colorstyle++;

  switch (colorstyle) {
  case 1:
    // White
    r=true;
    g=true;
    b=true;
    break;
  case 2:
    // Red
    r=true;
    g=false;
    b=false;
    break;  
  case 3:
    // Yellow
    r=true;
    g=true;
    b=false;
    break; 
  case 4:
    // Purple
    r=true;
    g=false;
    b=true;
    break; 
  case 5:
    // ?
    r=false;
    g=true;
    b=true;
    break;     
  default:
    // Green
    r=false;
    g=true;
    b=false;
    colorstyle = 0;
    break;
  }
  
}

unsigned long GetColor(int brightness) {
  return pixels.Color(
            r * constrain(brightness,0,max_brightness), 
            g * constrain(brightness,0,max_brightness), 
            b * constrain(brightness,0,max_brightness)
            );
}
